/*
 *  GEM MINE - The ROCK Linux Package Manager
 *  Copyright (C) 2002-2005 Clifford Wolf
 *  
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <string.h>
#include <stdio.h>
#include <unistd.h>

#include "memdb.h"

int compare_strings_reverse(char* left, char* right) {
        return strcmp(right, left);
}

int main(int argc, char** argv) {

	if(access("memdbtest_insert.txt",R_OK)) {
		fprintf(stderr,"unable to open test input file memdbtest_insert.txt\n");
		return 1;
	}
	if(access("memdbtest_remove.txt",R_OK)) {
		fprintf(stderr,"unable to open test input file memdbtest_remove.txt\n");
		return 1;
	}

	char buffer[1024];

	struct memdb_t memdb_type;

	memdb_init(&memdb_type);

	FILE *testfile = fopen("memdbtest_insert.txt", "r");
	while( fgets(buffer, 1024, testfile) != NULL) {
		char* key = strtok(buffer," \n");
		char* value = strtok(NULL,"\n");
		memdb_put(&memdb_type, key, value);
	}
	fclose(testfile);

	memdb_sort(&memdb_type, compare_strings_reverse);

	testfile = fopen("memdbtest_remove.txt", "r");
	while( fgets(buffer, 1024, testfile) != NULL) {
		char* key = strtok(buffer," \n");
		char* value = strtok(NULL,"\n");
		if(memdb_get(&memdb_type, key) == NULL) {
			fprintf(stderr,"missing entry in memdb, key '%s', value '%s'!\n", key, value);
			return 1;
		} else {
			memdb_remove(&memdb_type, key);
		}
	}
	fclose(testfile);

	testfile = fopen("memdbtest_insert.txt", "r");
	while( fgets(buffer, 1024, testfile) != NULL) {
		char* key = strtok(buffer," \n");
		char* value = strtok(NULL,"\n");
		if(memdb_get(&memdb_type, key) != NULL) {
			fprintf(stderr,"entry still in memdb, key '%s', value '%s'!\n", key, value);
			return 1;
		}
	}
	fclose(testfile);

	memdb_free(&memdb_type);

	return 0;
}
